# RoadBuilder

This is a track editor for the track_generator. (github.com/twyleg/track_generator)

The RoadBuilder has a userinterface to create tracks with the see what you get methode.

**Userinterface**

![Userinterface](doc/png/userinterface.png)

## Usage

Install via pip:

    pip install RoadBuilder

Run:

    RoadBuilder start

Install manual:

    Run the file "manual_setup/setup.bash"

Run:

    Run the file "manual_setup/start_gui.bash"

Use the .bat files if you are on a windows system.
